## Examples

The examples in this directory should just work with LED SHIM, although you'll need to add Twitter developer access tokens and secrets in the `twitter_monitor.py` example. You can get these at [https://dev.twitter.com/](https://dev.twitter.com/), after setting up a new application.

The examples in the `extra_examples` folder are designed to work with other pHATs and HATs, so be aware of that before trying them.
